@@ -32,23 +32,22 @@ inline dim3 opt_block_config(int x, int y)
 // from https://docs.nvidia.com/cuda/cuda-c-programming-guide/index.html#atomic-functions
 #if !defined(__CUDA_ARCH__) || __CUDA_ARCH__ >= 600
 #else
-    __device__ double atomicAdd(double* address, double val)
-    {
-        unsigned long long int* address_as_ull =
-                                (unsigned long long int*)address;
-        unsigned long long int old = *address_as_ull, assumed;
+__device__ double atomicAdd(double* address, double val)
+{
+    unsigned long long int* address_as_ull = (unsigned long long int*)address;
+    unsigned long long int old = *address_as_ull, assumed;
 
-        do {
-            assumed = old;
-            old = atomicCAS(address_as_ull, assumed,
-                            __double_as_longlong(val +
-                                __longlong_as_double(assumed)));
+    do
+    {
+        assumed = old;
+        old = atomicCAS(address_as_ull, assumed,
+                        __double_as_longlong(val + __longlong_as_double(assumed)));
 
         // Note: uses integer comparison to avoid hang in case of NaN (since NaN != NaN)
-        } while (assumed != old);
+    } while (assumed != old);
 
-        return __longlong_as_double(old);
-    }
+    return __longlong_as_double(old);
+}
 #endif
 
 #define CUDA_CHECK_ERRORS()                                                                        \
