@@ -1,6 +1,7 @@
 #include "ball_query.h"
 #include "chamfer_dist.h"
 #include "cubic_feature_sampling.h"
+#include "gridding.h"
 #include "interpolate.h"
 #include "metrics.h"
 #include "sampling.h"
@@ -23,4 +24,7 @@ PYBIND11_MODULE(TORCH_EXTENSION_NAME, m)
 
     m.def("cubic_feature_sampling", &cubic_feature_sampling);
     m.def("cubic_feature_sampling_grad", &cubic_feature_sampling_grad);
+
+    m.def("gridding", &gridding);
+    m.def("gridding_grad", &gridding_grad);
 }
