@@ -9,6 +9,7 @@ at::Tensor furthest_point_sampling(at::Tensor points, const int nsamples)
 {
     CHECK_CONTIGUOUS(points);
     CHECK_IS_FLOAT(points);
+    CHECK_CUDA(points);
 
     at::Tensor output = torch::zeros({points.size(0), nsamples},
                                      at::device(points.device()).dtype(at::ScalarType::Int));
@@ -16,16 +17,9 @@ at::Tensor furthest_point_sampling(at::Tensor points, const int nsamples)
     at::Tensor tmp = torch::full({points.size(0), points.size(1)}, 1e10,
                                  at::device(points.device()).dtype(at::ScalarType::Float));
 
-    if (points.type().is_cuda())
-    {
-        furthest_point_sampling_kernel_wrapper(points.size(0), points.size(1), nsamples,
-                                               points.DATA_PTR<float>(), tmp.DATA_PTR<float>(),
-                                               output.DATA_PTR<int>());
-    }
-    else
-    {
-        TORCH_CHECK(false, "CPU not supported");
-    }
+    furthest_point_sampling_kernel_wrapper(points.size(0), points.size(1), nsamples,
+                                           points.DATA_PTR<float>(), tmp.DATA_PTR<float>(),
+                                           output.DATA_PTR<int>());
 
     return output;
 }
